{
  inputs = {
    nixpkgs.url = "github:nixos/nixpkgs/nixpkgs-unstable";
    utils.url = "github:numtide/flake-utils";
    naersk.url = "github:nix-community/naersk";
  };

  outputs = { self, nixpkgs, utils, naersk }:
    utils.lib.eachDefaultSystem (system:
      let
        pkgs = nixpkgs.legacyPackages."${system}";
        naersk-lib = naersk.lib."${system}";
        macOS =
          if pkgs.stdenv.isDarwin then
            [ pkgs.darwin.apple_sdk.frameworks.Security ]
          else
            [ ];
      in
      rec {
        # `nix build`
        packages.zat = naersk-lib.buildPackage {
          pname = "zat";
          root = ./.;
          buildInputs = with pkgs; [ cmake libiconv ];
        };
        packages.default = packages.zat;

        # `nix run`
        apps.zat = utils.lib.mkApp {
          drv = packages.zat;
        };
        apps.default = apps.zat;

        # `nix develop`
        devShells.default = pkgs.mkShell {
          name = "zat";
          nativeBuildInputs = with pkgs; [ cmake libiconv rustup ] ++ macOS;
        };
      });
}
